@@ -344,7 +344,7 @@ class Tado:
         data = self._apiCall(cmd, "DELETE", {}, True)
         return data
 
-    def setZoneOverlay(self, zone, overlayMode, setTemp=None, duration=None, deviceType='HEATING', power="ON", mode=None, fanLevel=None, swing=None):
+    def setZoneOverlay(self, zone, overlayMode, setTemp=None, duration=None, deviceType='HEATING', power="ON", mode=None, fanLevel=None, swing=None, verticalSwing=None, horizontalSwing=None):
         """set current overlay for a zone"""
         # pylint: disable=C0103
 
@@ -357,12 +357,20 @@ class Tado:
 
         # fanLevel and swing are required for some devices and must be sent otherwise
         # you can't set some modes such as DRY
+        # Todo: Check if fanSpeed is still necessary
         if fanLevel is not None:
             post_data["setting"]["fanLevel"] = fanLevel
 
+        # Todo: Determine if "swing" is still in use by Tado.
         if swing is not None:
             post_data["setting"]["swing"] = swing
 
+        if verticalSwing is not None:
+            post_data["setting"]["verticalSwing"] = verticalSwing
+
+        if horizontalSwing is not None:
+            post_data["setting"]["horizontalSwing"] = horizontalSwing
+
         if setTemp is not None:
             post_data["setting"]["temperature"] = {"celsius": setTemp}
 
